@@ -328,7 +328,7 @@ def SS_breakdown(
 
     SS_equivalencies = {
         "H": ["H"],
-        "-": [" "],
+        "-": ["-"],
         "S": [" ", "S", "C", "T", "G", "I", "P"],
         " ": [" ", "S", "C", "T", "G", "I", "P"],
         "C": [" ", "S", "C", "T", "G", "I", "P"],
@@ -340,7 +340,12 @@ def SS_breakdown(
         "B": ["E", "B"],
     }
 
-    cur_SSDict = {"H": "helix", "E": "strand", "B": "strand"}
+    cur_SSDict = {
+        "H": "helix",
+        "E": "strand",
+        "B": "strand",
+        "-": "break",
+    }
 
     for i in range(len(ss)):
         if i == 0:
@@ -887,8 +892,8 @@ def initialize(
     T.List[str],
     T.List[T.Tuple[int, int]],
 ]:
-    # preface run
     id = args.name
+
     chain_id = args.chain_id
     print("\nRunning for: " + id)
 
@@ -1065,9 +1070,9 @@ def SSDraw(
             aa,
             ha="center",
             va="bottom",
-            fontsize=15,
+            fontsize=args.fontsize,
             fontfamily="monospace",
-            color="white",
+            color=args.fontcolor,
         )
 
     plt.ylim([0.5, 3])
